@@ -859,6 +859,11 @@ e_mapi_cal_util_object_to_comp (EMapiConnection *conn,
 	g_return_val_if_fail (object != NULL, NULL);
 	g_return_val_if_fail (use_uid != NULL, NULL);
 
+	if (e_mapi_debug_is_enabled ()) {
+		printf ("%s:\n", G_STRFUNC);
+		e_mapi_debug_dump_object (object, TRUE, 3);
+	}
+
 	switch (kind) {
 		case ICAL_VEVENT_COMPONENT:
 		case ICAL_VTODO_COMPONENT:
@@ -998,7 +1003,7 @@ e_mapi_cal_util_object_to_comp (EMapiConnection *conn,
 		if (location && *location)
 			icalcomponent_set_location (ical_comp, location);
 
-		b = e_mapi_util_find_array_propval (&object->properties, PidLidAppointmentSubType);;
+		b = e_mapi_util_find_array_propval (&object->properties, PidLidAppointmentSubType);
 		all_day = b && *b;
 
 		bin = e_mapi_util_find_array_propval (&object->properties, PidLidAppointmentTimeZoneDefinitionStartDisplay);
@@ -1008,6 +1013,12 @@ e_mapi_cal_util_object_to_comp (EMapiConnection *conn,
 			g_free (buf);
 		}
 
+		if (!dtstart_tz_location) {
+			bin = e_mapi_util_find_array_propval (&object->properties, PidLidTimeZoneStruct);
+			if (bin)
+				dtstart_tz_location = e_mapi_cal_tz_util_ical_from_zone_struct (bin->lpb, bin->cb);
+		}
+
 		if (e_mapi_util_find_array_datetime_propval (&t, &object->properties, PidLidAppointmentStartWhole) == MAPI_E_SUCCESS) {
 			icaltimezone *zone = dtstart_tz_location ? icaltimezone_get_builtin_timezone (dtstart_tz_location) : utc_zone;
 			prop = icalproperty_new_dtstart (icaltime_from_timet_with_zone (t.tv_sec, all_day, zone));
@@ -1025,6 +1036,12 @@ e_mapi_cal_util_object_to_comp (EMapiConnection *conn,
 			g_free (buf);
 		}
 
+		if (!dtend_tz_location) {
+			bin = e_mapi_util_find_array_propval (&object->properties, PidLidTimeZoneStruct);
+			if (bin)
+				dtend_tz_location = e_mapi_cal_tz_util_ical_from_zone_struct (bin->lpb, bin->cb);
+		}
+
 		if (e_mapi_util_find_array_datetime_propval (&t, &object->properties, PidLidAppointmentEndWhole) == MAPI_E_SUCCESS) {
 			icaltimezone *zone;
 
@@ -2188,5 +2205,10 @@ e_mapi_cal_utils_comp_to_object (EMapiConnection *conn,
 
 	e_mapi_cal_utils_add_attachments (object, comp);
 
+	if (e_mapi_debug_is_enabled ()) {
+		printf ("%s:\n", G_STRFUNC);
+		e_mapi_debug_dump_object (object, TRUE, 3);
+	}
+
 	return TRUE;
 }
